-- vim: ts=2 sw=2 ai et enc=utf8 fenc=utf8

local RC = RaidChecklist
local P = RaidChecklistPetFamilies

if not RC then return end

RC.petproviders = { }
for i,b in ipairs (RC.buffs) do RC.petproviders[b] = {} end
for i,b in ipairs (RC.debuffs) do RC.petproviders[b] = {} end
for i,b in ipairs (RC.dispels) do RC.petproviders[b] = {} end
for i,b in ipairs (RC.ccs) do RC.petproviders[b] = {} end
for i,b in ipairs (RC.miscs) do RC.petproviders[b] = {} end

local B = RC.buffs
local C = RC.ccs
local D = RC.debuffs
local S = RC.dispels
local M = RC.miscs

local matrix = {
  [P.BAT]         = { },
  [P.BEAR]        = { D.DEMOROAR },
  [P.BEETLE]      = { },
  [P.BIRDOFPREY]  = { M.DISARM },
  [P.BOAR]        = { D.BLEEDDMGTAKEN },
  [P.CARRIONBIRD] = { D.DEMOROAR },
  [P.CAT]         = { B.AGISTR },
  [P.CHIMAERA]    = { },
  [P.COREHOUND]   = { B.BLOODLUST, D.CASTSPD },
  [P.CRAB]        = { },
  [P.CROCOLISK]   = { },
  [P.DEVILSAUR]   = { B.CRIT, D.MORTALSTRIKE },
  [P.DOG]         = { },
  [P.DOOMGUARD]   = { },
  [P.DRAGONHAWK]  = { D.SPELLDMGTAKEN },
  [P.FELGUARD]    = { D.MORTALSTRIKE },
  [P.FELHUNTER]   = { B.MANA, B.MANAREGEN, M.INTERRUPT },
  [P.FOX]         = { D.ATTACKSPD },
  [P.GHOUL]       = { },
  [P.GORILLA]     = { M.INTERRUPT },
  [P.HYENA]       = { D.BLEEDDMGTAKEN },
  [P.IMP]         = { },
  [P.MONKEY]      = { },
  [P.MOTH]        = { },
  [P.NETHERRAY]   = { },
  [P.RAPTOR]      = { D.SUNDER },
  [P.RAVAGER]     = { D.PHYSDMGTAKEN },
  [P.RHINO]       = { D.BLEEDDMGTAKEN },
  [P.SCORPID]     = { M.DISARM },
  [P.SERPENT]     = { D.SUNDER },
  [P.SHALESPIDER] = { B.STATS },
  [P.SILITHID]    = { B.STAM },
  [P.SPIDER]      = { },
  [P.SPIRITBEAST] = { B.AGISTR },
  [P.SPOREBAT]    = { D.CASTSPD },
  [P.SUCCUBUS]    = { M.KNOCKBACK, C.CCHUMANOIDS },
  [P.TALLSTRIDER] = { D.ATTACKSPD },
  [P.TURTLE]      = { },
  [P.VOIDWALKER]  = { },
  [P.WARPSTALKER] = { },
  [P.WASP]        = { },
  [P.WATERELEMENTAL] = { },
  [P.WINDSERPENT] = { D.SPELLDMGTAKEN },
  [P.WOLF]        = { B.CRIT },
  [P.WORM]        = { D.PHYSDMGTAKEN },
} 


local function remove_petprovider (rguid)
  for key,guidlist in pairs (RC.petproviders) do
    guidlist[rguid] = nil
  end
  if (RC.OnRefresh) then RC:OnRefresh () end
end


local function add_petprovider (buff, guid)
  RC.petproviders[buff][guid] = true
  if (RC.OnRefresh) then RC:OnRefresh () end
end


local RCB = RaidChecklist.button

function RCB:UNIT_PET (unit)
  -- Filter out units we don't care about
  local filtered = string.gsub (unit, "%d", "")
  if filtered ~= "player" and filtered ~= "party" and filtered ~= "raid" then
    return
  end

  local guid = UnitGUID (unit)
  if not guid then return end
  remove_petprovider (guid)
  local family = UnitCreatureFamily (unit.."pet")
  if not family then return end
  local list = matrix[family]
  if not list then
    -- Maybe we haven't got the right family name, or I messed up the locale info...
    DEFAULT_CHAT_FRAME:AddMessage("RaidChecklist: missing family '"..(family or "nil").."', please report this so it can be fixed!")
    return
  end
  for i,key in ipairs (list) do
    add_petprovider (key, guid)
  end
end

RCB:RegisterEvent("UNIT_PET")

